"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

var _Label = _interopRequireDefault(require("../Label"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/**
 * Generates a `input` element of type `radio` that is wrapped in a `Label`.
 * @param {Object} props - Properties passed to component
 * @returns {ReactElement}
 */
var Radio = function Radio(_ref) {
  var checked = _ref.checked,
      className = _ref.className,
      defaultChecked = _ref.defaultChecked,
      isDisabled = _ref.isDisabled,
      label = _ref.label,
      labelWeight = _ref.labelWeight,
      name = _ref.name,
      onChange = _ref.onChange,
      _ref$testSection = _ref.testSection,
      testSection = _ref$testSection === void 0 ? null : _ref$testSection,
      props = _objectWithoutProperties(_ref, ["checked", "className", "defaultChecked", "isDisabled", "label", "labelWeight", "name", "onChange", "testSection"]);

  var labelClassNames = (0, _classnames["default"])({
    "flush--bottom": true,
    "push--left": true,
    "weight--light": labelWeight === "light",
    "weight--normal": labelWeight === "normal",
    "weight--bold": labelWeight === "bold",
    "cursor--pointer": true,
    "oui-label--disabled": isDisabled
  });
  var classes = (0, _classnames["default"])({
    "flex--none": true
  }, className);
  return _react["default"].createElement(_Label["default"], {
    "data-test-section": "".concat(testSection, "-label")
  }, _react["default"].createElement("div", {
    className: "flex"
  }, _react["default"].createElement("input", _extends({
    "data-oui-component": true,
    type: "radio",
    name: name,
    defaultChecked: defaultChecked,
    checked: checked,
    className: classes,
    disabled: isDisabled,
    onChange: onChange,
    "data-test-section": testSection,
    style: {
      marginTop: "0.3em"
    }
  }, props)), _react["default"].createElement("div", {
    className: labelClassNames
  }, label)));
};

Radio.propTypes = {
  /** Boolean to set radio input, for controlled component  */
  checked: _propTypes["default"].bool,

  /** CSS class names. */
  className: _propTypes["default"].string,

  /** Boolean for how radio input renders initially  */
  defaultChecked: _propTypes["default"].bool,

  /** Prevents radio input from being modified and appears disabled */
  isDisabled: _propTypes["default"].bool,

  /** Text that describes the radio input */
  label: _propTypes["default"].oneOfType([_propTypes["default"].string, _propTypes["default"].node]),

  /** Font weight for the label text */
  labelWeight: _propTypes["default"].oneOf(["light", "normal", "bold"]),

  /**
  String that can be used to identify a set of radio inputs so that only one
  in the set is checked at any given time.
  */
  name: _propTypes["default"].string.isRequired,

  /** Function that fires when the radio input is clicked */
  onChange: _propTypes["default"].func,

  /** Hook for automated JavaScript tests */
  testSection: _propTypes["default"].string
};
Radio.defaultProps = {
  labelWeight: "normal"
};
var _default = Radio;
exports["default"] = _default;